@@ -4,10 +4,10 @@
 # Licensed under the terms of the MIT License
 # (see LICENSE.txt for details)
 # -----------------------------------------------------------------------------
+
 """Provides QtWebSockets classes and functions."""
 
-# Local imports
-from . import PYSIDE2, PYQT5, PYQT6, PythonQtError
+from . import PYQT5, PYQT6, PYSIDE2, PYSIDE6
 
 if PYQT5:
     from PyQt5.QtWebSockets import *
@@ -15,5 +15,5 @@ elif PYQT6:
     from PyQt6.QtWebSockets import *
 elif PYSIDE2:
     from PySide2.QtWebSockets import *
-else:
-    raise PythonQtError('No Qt bindings could be found')
+elif PYSIDE6:
+    from PySide6.QtWebSockets import *
