@@ -1,9 +1,11 @@
 import pytest
 
+from qtpy.tests.utils import pytest_importorskip
+
 
 def test_qtstatemachine():
     """Test the qtpy.QtStateMachine namespace"""
-    QtStateMachine = pytest.importorskip("qtpy.QtStateMachine")
+    QtStateMachine = pytest_importorskip("qtpy.QtStateMachine")
 
     assert QtStateMachine.QAbstractState is not None
     assert QtStateMachine.QAbstractTransition is not None
